Module: OpenTelemetry::Instrumentation

Defined in:
lib/opentelemetry/instrumentation.rb,
lib/opentelemetry/instrumentation/net/ldap.rb,
lib/opentelemetry/instrumentation/net/ldap/version.rb,
lib/opentelemetry/instrumentation/net/ldap/instrumentation.rb,
lib/opentelemetry/instrumentation/net/ldap/attribute_mapper.rb,
lib/opentelemetry/instrumentation/net/ldap/instrumentation_service.rb,
lib/opentelemetry/instrumentation/net/ldap/patches/instrumentation.rb

Overview

"Instrumentation" are specified by https://github.com/open-telemetry/opentelemetry-specification/blob/784635d01d8690c8f5fcd1f55bdbc8a13cf2f4f2/specification/glossary.md#instrumentation-library

Instrumentation should be able to handle the case when the library is not installed on a user's system.

Defined Under Namespace

Modules: Net